from os import path

from django.contrib.staticfiles.finders import BaseFinder
from django.core.exceptions import ImproperlyConfigured
from django.conf import settings


class StaticRootFinder(BaseFinder):
    """
    A static files finder to find files in the STATIC_ROOT directory
    """

    def find(self, file_path, all=False):
        if all:
            raise NotImplementedError("'all' not implemented")

        static_root = getattr(settings, 'STATIC_ROOT', '')

        if not static_root:
            raise ImproperlyConfigured(
                'django_static_root_finder requires STATIC_ROOT'
                ' to be set in settings.py.'
            )

        static_root_file_path = path.join(static_root, file_path)

        if path.isfile(static_root_file_path):
            return static_root_file_path

    def list(self, ignore_patterns):
        # Do nothing for collectstatic
        return []



from setuptools import setup

setup(
    name='django-static-root-finder',
    version='0.2.1',
    author='Robin',
    author_email='robin.winslow@canonical.com',
    url='https://github.com/ubuntudesign/django-static-root-finder',
    packages=[
        'django_static_root_finder'
    ],
    description=(
        'A static files finder to find files in the STATIC_ROOT directory.'
    ),
    long_description=open('README.rst').read(),
    install_requires=[
        "Django >= 1.3",
    ],
)
